summaryrefslogtreecommitdiff
path: root/drivers/input/keyboard/nomadik-ske-keypad.c
diff options
context:
space:
mode:
Diffstat (limited to 'drivers/input/keyboard/nomadik-ske-keypad.c')
-rw-r--r--drivers/input/keyboard/nomadik-ske-keypad.c8
1 files changed, 6 insertions, 2 deletions
diff --git a/drivers/input/keyboard/nomadik-ske-keypad.c b/drivers/input/keyboard/nomadik-ske-keypad.c
index e791b16c6b1..9a3e7dfb605 100644
--- a/drivers/input/keyboard/nomadik-ske-keypad.c
+++ b/drivers/input/keyboard/nomadik-ske-keypad.c
@@ -367,9 +367,13 @@ static void ske_keypad_scan_work(struct work_struct *work)
}
if (keypad->key_pressed) {
/* Key still pressed, schedule work to poll changes in 50 ms */
schedule_delayed_work(&keypad->scan_work,
- msecs_to_jiffies(50));
+ msecs_to_jiffies(100));
} else {
/* For safty measure, clear interrupt once more */
ske_keypad_set_bits(keypad, SKE_ICR, 0x0, SKE_KPICA);
@@ -367,9 +367,13 @@ static void ske_keypad_scan_work(struct work_struct *work)
}
if (keypad->key_pressed) {
- /* Key still pressed, schedule work to poll changes in 50 ms */
+ /*
+ * Key still pressed, schedule work to poll changes in 100 ms
+ * After increasing the delay from 50 to 100 it is taking
+ * 2% to 3% load on average.
+ */
schedule_delayed_work(&keypad->scan_work,